 # coding: utf-8

from rest_framework import viewsets


class QuerysetMixin:
    """Mixin to inject filter capabilities to API
    """

    def get_filters(self):
        filters = dict()
        for key, value in self.request.GET.items():
            if key.startswith('filter__'):
                key = key[8:]
                filters[key] = value
        return filters

    def get_excludes(self):
        excludes = dict()
        for key, value in self.request.GET.items():
            if key.startswith('exclude__'):
                key = key[9:]
                excludes[key] = value
        return excludes

    def get_order_by(self):
        order_by = list()
        for key, value in self.request.GET.items():
            if key.startswith('order_by__'):
                # key = key[10:]
                order_by.append(value)
        return order_by

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(QuerysetMixin, self).get_queryset()
        if filters:
            queryset = queryset.filter(**filters)
        if excludes:
            queryset = queryset.exclude(**excludes)
        if order_by:
            queryset = queryset.order_by(*order_by).distinct()
        return queryset

    @property
    def paginator(self):
        if self.request.query_params.get('no_page'):
            self.pagination_class = None
        return super(QuerysetMixin, self).paginator


class FilterModelViewSet(QuerysetMixin, viewsets.ModelViewSet):
    pass
